## [0.1.0rc1] - 2022-05-27

- Add dbt project for testing
- Add `--dbt-project-dir` pytest flag that points to the dbt project directory

## [0.1.0.dev2] - 2022-01-28

- Implement use as pytest plugin

## [0.1.0.dev1] - 2022-01-28

- Set-up repo
